==> 0.0.1.tar.gz: android/src/main/java/com/pranjal/calendarnotificationprovider/ReminderBroadcastReceiver.java <==
package com.pranjal.calendarnotificationprovider;

import android.app.Notification;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.content.BroadcastReceiver;
import android.content.ContentResolver;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.net.Uri;
import android.provider.CalendarContract;
import android.util.Log;

import androidx.core.app.NotificationCompat;

import com.pranjal.calendarnotificationprovider.models.DynamicText;
import com.pranjal.calendarnotificationprovider.models.SharedPrefKeys;

import java.util.List;

import io.flutter.embedding.engine.plugins.broadcastreceiver.BroadcastReceiverControlSurface;

public class ReminderBroadcastReceiver extends BroadcastReceiver  {
    private static final String TAG = "ReminderBroadReceiver";
    public static final String NOTIFICATION_CHANNEL_ID = "61741" ;
    private final static String default_notification_channel_id = "default" ;
    @Override
    public void onReceive(Context context, Intent intent) {

        String action = intent.getAction() ;
//        Log. e ( "USBer" , action) ;

        assert action != null;
        if(!action.equals("android.intent.action.EVENT_REMINDER")){
            return;
        }
        Uri uri = intent.getData();
        ContentResolver cr = context.getContentResolver();
        String sUri = uri.toString();
        Uri alertUri = Uri.parse(sUri);
        String alarmTime = uri.getLastPathSegment();
        String[] projection = new String[] {
                CalendarContract.CalendarAlerts.OWNER_ACCOUNT,
                CalendarContract.CalendarAlerts.EVENT_ID,
                CalendarContract.CalendarAlerts.TITLE,
                CalendarContract.CalendarAlerts.DESCRIPTION,
                CalendarContract.CalendarAlerts.DTSTART,
                CalendarContract.CalendarAlerts.DTEND
        };

        String selection = CalendarContract.CalendarAlerts.ALARM_TIME + "=?";

        Cursor c = cr.query(CalendarContract.CalendarAlerts.CONTENT_URI_BY_INSTANCE,
                projection,
                selection,
                new String[] {alarmTime},
                null);
        String eventId,title = "",description = "",owner_account,startTime = "",endTime = "";

        if (c != null) {
            c.moveToFirst();
            owner_account = c.getString(c.getColumnIndex(c.getColumnName(0)));
            eventId = c.getString(c.getColumnIndex(c.getColumnName(1)));
            title = c.getString(c.getColumnIndex(c.getColumnName(2)));
            description = c.getString(c.getColumnIndex(c.getColumnName(3)));
            startTime = c.getString(c.getColumnIndex(c.getColumnName(4)));
            endTime = c.getString(c.getColumnIndex(c.getColumnName(5)));
            c.close();
        }
        SharedPrefsManager prefsManager = new SharedPrefsManager(context,context.getPackageName(),0);
        String contentTitle = NotificationContentManager.getTitle(context,prefsManager,title,description,startTime,endTime);
        String contentDescription = NotificationContentManager.getDescription(context,prefsManager,title,description,startTime,endTime);
        String appOpenName = NotificationContentManager.getAppOpenName(context,prefsManager);

//        Cursor alertCursor = cr.query(alertUri, ALERT_PROJECTION,
//                null /* selection */, null, null /* sort order */);

//        StringBuilder sb = new StringBuilder();
//        sb.append("Action: " + intent.getAction() + "\n");
//        sb.append("URI: " + intent.toUri(Intent.URI_INTENT_SCHEME).toString() + "\n");
//        String log = sb.toString();
//        Log.d(TAG, log);
//        Log.d(TAG,"dsanjkasknjd");
//        SharedPreferences sharedPreferences = context.getSharedPreferences("abcd",Context.MODE_PRIVATE);
//        String temp = sharedPreferences.getString("abcd","");
        String temp = prefsManager.getPreferences("abcd",context.getPackageName());

        NotificationCompat.Builder builder = new NotificationCompat.Builder(context , default_notification_channel_id ) ;
        builder.setContentTitle( contentTitle ) ;
//        if(!appOpenName.equals("")) {
//            PackageManager pm = context.getPackageManager();
//            try {
//                PackageInfo info = pm.getPackageInfo(appOpenName, PackageManager.GET_META_DATA);
//                intent = new Intent(Intent.ACTION_SEND);
//                intent.setPackage(appOpenName);
//                intent.setType("text/plain");
//            } catch (PackageManager.NameNotFoundException e) {
//                // Package not found
//                intent = null;
//                e.printStackTrace();
//            }
//        }
//        if(intent!=null){
//            PendingIntent clickPendingIntent = PendingIntent.getActivity(
//                    context,
//                    0,
//                    intent,
//                    PendingIntent.FLAG_UPDATE_CURRENT);
////            builder.setContentIntent(clickPendingIntent);
//            builder.addAction(R.drawable.launch_background,"Open App",clickPendingIntent);
//        }

        builder.setContentText( contentDescription ) ;
        Bitmap largeIcon =  BitmapFactory.decodeResource(context.getResources(),R.drawable.launch_background);
//        builder.setLargeIcon(largeIcon);
//        new NotificationCompat.BigPictureStyle().bigLargeIcon(largeIcon).bigPicture(largeIcon);
        builder.setStyle(
                new NotificationCompat.BigTextStyle().bigText(contentDescription)
//                new NotificationCompat.BigPictureStyle().bigLargeIcon(largeIcon).bigPicture(largeIcon)
        );

        builder.setSmallIcon(R.drawable.launch_background ) ;
        builder.setAutoCancel( true ) ;
        builder.setChannelId( NOTIFICATION_CHANNEL_ID ) ;
        Notification notification = builder.build() ;
        notification.flags |= Notification.DEFAULT_SOUND;
        NotificationManager notificationManager = (NotificationManager) context.getSystemService(Context. NOTIFICATION_SERVICE ) ;
        if (android.os.Build.VERSION. SDK_INT >= android.os.Build.VERSION_CODES. O ) {
            int importance = NotificationManager. IMPORTANCE_HIGH ;
            NotificationChannel notificationChannel = new NotificationChannel( NOTIFICATION_CHANNEL_ID , "NOTIFICATION_CHANNEL_NAMEee" , importance) ;
            assert notificationManager != null;
            notificationManager.createNotificationChannel(notificationChannel) ;
        }

//        PackageManager pm = context.getPackageManager();
        Log.d("will try to package",temp);
//        Intent launchIntent = pm.getLaunchIntentForPackage(temp);
//        launchIntent.putExtra("some_data", "value");
//         context.startActivity(launchIntent);
        assert notificationManager != null;
        notificationManager.notify( 1 , notification) ;
    }

}

==> 0.0.2.tar.gz: android/src/main/java/com/pranjal/calendarnotificationprovider/ReminderBroadcastReceiver.java <==
package com.pranjal.calendarnotificationprovider;

import android.app.Notification;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.content.BroadcastReceiver;
import android.content.ContentResolver;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.net.Uri;
import android.provider.CalendarContract;
import android.util.Log;

import androidx.core.app.NotificationCompat;

import com.pranjal.calendarnotificationprovider.models.DynamicText;
import com.pranjal.calendarnotificationprovider.models.SharedPrefKeys;

import java.util.List;

import io.flutter.embedding.engine.plugins.broadcastreceiver.BroadcastReceiverControlSurface;

public class ReminderBroadcastReceiver extends BroadcastReceiver  {
    private static final String TAG = "ReminderBroadReceiver";
    public static final String NOTIFICATION_CHANNEL_ID = "61741" ;
    private final static String default_notification_channel_id = "default" ;
    @Override
    public void onReceive(Context context, Intent intent) {

        String action = intent.getAction() ;
//        Log. e ( "USBer" , action) ;

        assert action != null;
        if(!action.equals("android.intent.action.EVENT_REMINDER")){
            return;
        }
        Uri uri = intent.getData();
        ContentResolver cr = context.getContentResolver();
        String sUri = uri.toString();
        Uri alertUri = Uri.parse(sUri);
        String alarmTime = uri.getLastPathSegment();
        String[] projection = new String[] {
                CalendarContract.CalendarAlerts.OWNER_ACCOUNT,
                CalendarContract.CalendarAlerts.EVENT_ID,
                CalendarContract.CalendarAlerts.TITLE,
                CalendarContract.CalendarAlerts.DESCRIPTION,
                CalendarContract.CalendarAlerts.DTSTART,
                CalendarContract.CalendarAlerts.DTEND
        };

        String selection = CalendarContract.CalendarAlerts.ALARM_TIME + "=?";

        Cursor c = cr.query(CalendarContract.CalendarAlerts.CONTENT_URI_BY_INSTANCE,
                projection,
                selection,
                new String[] {alarmTime},
                null);
        String eventId,title = "",description = "",owner_account,startTime = "",endTime = "";

        if (c != null) {
            c.moveToFirst();
            owner_account = c.getString(c.getColumnIndex(c.getColumnName(0)));
            eventId = c.getString(c.getColumnIndex(c.getColumnName(1)));
            title = c.getString(c.getColumnIndex(c.getColumnName(2)));
            description = c.getString(c.getColumnIndex(c.getColumnName(3)));
            startTime = c.getString(c.getColumnIndex(c.getColumnName(4)));
            endTime = c.getString(c.getColumnIndex(c.getColumnName(5)));
            c.close();
        }
        SharedPrefsManager prefsManager = new SharedPrefsManager(context,context.getPackageName(),0);
        String contentTitle = NotificationContentManager.getTitle(context,prefsManager,title,description,startTime,endTime);
        String contentDescription = NotificationContentManager.getDescription(context,prefsManager,title,description,startTime,endTime);
        String appOpenName = NotificationContentManager.getAppOpenName(context,prefsManager);

//        Cursor alertCursor = cr.query(alertUri, ALERT_PROJECTION,
//                null /* selection */, null, null /* sort order */);

//        StringBuilder sb = new StringBuilder();
//        sb.append("Action: " + intent.getAction() + "\n");
//        sb.append("URI: " + intent.toUri(Intent.URI_INTENT_SCHEME).toString() + "\n");
//        String log = sb.toString();
//        Log.d(TAG, log);
//        Log.d(TAG,"dsanjkasknjd");
//        SharedPreferences sharedPreferences = context.getSharedPreferences("abcd",Context.MODE_PRIVATE);
//        String temp = sharedPreferences.getString("abcd","");
        String temp = prefsManager.getPreferences("abcd",context.getPackageName());

        NotificationCompat.Builder builder = new NotificationCompat.Builder(context , default_notification_channel_id ) ;
        builder.setContentTitle( contentTitle ) ;
//        if(!appOpenName.equals("")) {
//            PackageManager pm = context.getPackageManager();
//            try {
//                PackageInfo info = pm.getPackageInfo(appOpenName, PackageManager.GET_META_DATA);
//                intent = new Intent(Intent.ACTION_SEND);
//                intent.setPackage(appOpenName);
//                intent.setType("text/plain");
//            } catch (PackageManager.NameNotFoundException e) {
//                // Package not found
//                intent = null;
//                e.printStackTrace();
//            }
//        }
//        if(intent!=null){
//            PendingIntent clickPendingIntent = PendingIntent.getActivity(
//                    context,
//                    0,
//                    intent,
//                    PendingIntent.FLAG_UPDATE_CURRENT);
////            builder.setContentIntent(clickPendingIntent);
//            builder.addAction(R.drawable.launch_background,"Open App",clickPendingIntent);
//        }

        builder.setContentText( contentDescription ) ;
        Bitmap largeIcon =  BitmapFactory.decodeResource(context.getResources(),R.drawable.launch_background);
//        builder.setLargeIcon(largeIcon);
//        new NotificationCompat.BigPictureStyle().bigLargeIcon(largeIcon).bigPicture(largeIcon);
        builder.setStyle(
                new NotificationCompat.BigTextStyle().bigText(description+"\n ")
//                new NotificationCompat.BigPictureStyle().bigLargeIcon(largeIcon).bigPicture(largeIcon)
        );

        builder.setSmallIcon(R.drawable.launch_background ) ;
        builder.setAutoCancel( true ) ;
        builder.setChannelId( NOTIFICATION_CHANNEL_ID ) ;
        Notification notification = builder.build() ;
        notification.flags |= Notification.DEFAULT_SOUND;
        NotificationManager notificationManager = (NotificationManager) context.getSystemService(Context. NOTIFICATION_SERVICE ) ;
        if (android.os.Build.VERSION. SDK_INT >= android.os.Build.VERSION_CODES. O ) {
            int importance = NotificationManager. IMPORTANCE_HIGH ;
            NotificationChannel notificationChannel = new NotificationChannel( NOTIFICATION_CHANNEL_ID , "NOTIFICATION_CHANNEL_NAMEee" , importance) ;
            assert notificationManager != null;
            notificationManager.createNotificationChannel(notificationChannel) ;
        }

//        PackageManager pm = context.getPackageManager();
        Log.d("will try to package",temp);
//        Intent launchIntent = pm.getLaunchIntentForPackage(temp);
//        launchIntent.putExtra("some_data", "value");
//         context.startActivity(launchIntent);
        assert notificationManager != null;
        notificationManager.notify( 1 , notification) ;
    }

}
